/**
 * Core LLM abstraction for generating text
 */
import { LLMProvider } from './provider.js';
import { FunctionDefinition, GenerateOptions, LLMResponse, Message } from './types.js';
/**
 * Generate text using the specified LLM provider
 *
 * @param provider The LLM provider implementation
 * @param options Options for generation including messages, functions, etc.
 * @returns A response containing generated text and/or tool calls
 */
export declare function generateText(provider: LLMProvider, options: GenerateOptions): Promise<LLMResponse>;
/**
 * Format function definitions for provider compatibility
 *
 * @param functions Function definitions
 * @returns Normalized function definitions
 */
export declare function normalizeFunctionDefinitions(functions?: FunctionDefinition[]): FunctionDefinition[];
/**
 * Convert messages to provider-specific format if needed
 *
 * @param messages Array of messages
 * @returns Normalized messages
 */
export declare function normalizeMessages(messages: Message[]): Message[];
//# sourceMappingURL=core.d.ts.map