/**
 * Provider registry and factory implementations
 */
import { ProviderOptions, GenerateOptions, LLMResponse } from './types.js';
/**
 * Interface for LLM providers
 */
export interface LLMProvider {
    /**
     * Provider name (e.g., 'openai', 'anthropic', etc.)
     */
    name: string;
    /**
     * Provider-specific identifier (e.g., 'openai.chat', 'anthropic.messages', etc.)
     */
    provider: string;
    /**
     * Model name (e.g., 'gpt-4', 'claude-3', etc.)
     */
    model: string;
    /**
     * Generate text using this provider
     *
     * @param options Generation options
     * @returns Response with text and/or tool calls
     */
    generateText(options: GenerateOptions): Promise<LLMResponse>;
}
/**
 * Create a provider instance
 */
export declare function createProvider(providerType: string, model: string, options?: ProviderOptions): LLMProvider;
/**
 * Register a new provider implementation
 */
export declare function registerProvider(providerType: string, factory: (model: string, options: ProviderOptions) => LLMProvider): void;
//# sourceMappingURL=provider.d.ts.map