import type { Browser, Page } from '@playwright/test';
export interface BrowserConfig {
    headless?: boolean;
    defaultTimeout?: number;
}
export interface BrowserSession {
    browser: Browser;
    page: Page;
    id: string;
}
export declare enum BrowserErrorCode {
    LAUNCH_FAILED = "LAUNCH_FAILED",
    NAVIGATION_FAILED = "NAVIGATION_FAILED",
    SESSION_ERROR = "SESSION_ERROR",
    SELECTOR_ERROR = "SELECTOR_ERROR",
    TIMEOUT = "TIMEOUT",
    UNKNOWN = "UNKNOWN",
    SELECTOR_INVALID = "SELECTOR_INVALID",
    ELEMENT_NOT_FOUND = "ELEMENT_NOT_FOUND"
}
export declare class BrowserError extends Error {
    code: BrowserErrorCode;
    cause?: unknown | undefined;
    constructor(message: string, code: BrowserErrorCode, cause?: unknown | undefined);
}
export declare enum SelectorType {
    CSS = "css",
    XPATH = "xpath",
    TEXT = "text",
    ROLE = "role",
    TESTID = "testid"
}
export interface SelectorOptions {
    type?: SelectorType;
    timeout?: number;
    visible?: boolean;
}
export declare const browserSessions: Map<string, BrowserSession>;
export type BrowserAction = {
    actionType: 'goto';
    url: string;
} | {
    actionType: 'click';
    selector: string;
    selectorType?: SelectorType;
} | {
    actionType: 'type';
    selector: string;
    text: string;
    selectorType?: SelectorType;
} | {
    actionType: 'wait';
    selector: string;
    selectorType?: SelectorType;
} | {
    actionType: 'content';
} | {
    actionType: 'close';
};
//# sourceMappingURL=types.d.ts.map