import { z } from 'zod';
import { zodToJsonSchema } from 'zod-to-json-schema';
import { userPrompt } from '../../utils/userPrompt.js';
const parameterSchema = z.object({
    prompt: z.string().describe('The prompt message to display to the user'),
});
const returnSchema = z.object({
    userText: z.string().describe("The user's response"),
});
export const userPromptTool = {
    name: 'userPrompt',
    description: 'Prompts the user for input and returns their response',
    logPrefix: '🗣️',
    parameters: parameterSchema,
    parametersJsonSchema: zodToJsonSchema(parameterSchema),
    returns: returnSchema,
    returnsJsonSchema: zodToJsonSchema(returnSchema),
    execute: async ({ prompt }, { logger }) => {
        logger.verbose(`Prompting user with: ${prompt}`);
        const response = await userPrompt(prompt);
        logger.verbose(`Received user response: ${response}`);
        return { userText: response };
    },
    logParameters: () => { },
    logReturns: () => { },
};
//# sourceMappingURL=userPrompt.js.map