import { z } from 'zod';
import { Tool } from '../../core/types.js';
import type { ChildProcess } from 'child_process';
type ProcessState = {
    process: ChildProcess;
    command: string;
    stdout: string[];
    stderr: string[];
    state: {
        completed: boolean;
        signaled: boolean;
        exitCode: number | null;
    };
    showStdIn: boolean;
    showStdout: boolean;
};
export declare const processStates: Map<string, ProcessState>;
declare const parameterSchema: z.ZodObject<{
    command: z.ZodString;
    description: z.ZodString;
    timeout: z.ZodOptional<z.ZodNumber>;
    showStdIn: z.ZodOptional<z.ZodBoolean>;
    showStdout: z.ZodOptional<z.ZodBoolean>;
}, "strip", z.ZodTypeAny, {
    command: string;
    description: string;
    timeout?: number | undefined;
    showStdIn?: boolean | undefined;
    showStdout?: boolean | undefined;
}, {
    command: string;
    description: string;
    timeout?: number | undefined;
    showStdIn?: boolean | undefined;
    showStdout?: boolean | undefined;
}>;
declare const returnSchema: z.ZodUnion<[z.ZodObject<{
    mode: z.ZodLiteral<"sync">;
    stdout: z.ZodString;
    stderr: z.ZodString;
    exitCode: z.ZodNumber;
    error: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    mode: "sync";
    stdout: string;
    stderr: string;
    exitCode: number;
    error?: string | undefined;
}, {
    mode: "sync";
    stdout: string;
    stderr: string;
    exitCode: number;
    error?: string | undefined;
}>, z.ZodObject<{
    mode: z.ZodLiteral<"async">;
    instanceId: z.ZodString;
    stdout: z.ZodString;
    stderr: z.ZodString;
    error: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    mode: "async";
    stdout: string;
    stderr: string;
    instanceId: string;
    error?: string | undefined;
}, {
    mode: "async";
    stdout: string;
    stderr: string;
    instanceId: string;
    error?: string | undefined;
}>]>;
type Parameters = z.infer<typeof parameterSchema>;
type ReturnType = z.infer<typeof returnSchema>;
export declare const shellStartTool: Tool<Parameters, ReturnType>;
export {};
//# sourceMappingURL=shellStart.d.ts.map